//
// bricks (4096 uncompressed bytes)
//
/*extern const*/ unsigned char bricks_Bitmap[4096] = {
0x0b, 0x0b, 0x0d, 0x05, 0x0d, 0x05, 0x05, 0x05, 0x03, 0x03, 0x0c, 0x03, 0x0f, 0x03, 0x03, 0x05, 
0x03, 0x03, 0x05, 0x03, 0x03, 0x03, 0x03, 0x0f, 0x03, 0x0f, 0x0c, 0x0c, 0x03, 0x03, 0x0c, 0x03, 
0x05, 0x0b, 0x0d, 0x05, 0x0d, 0x05, 0x05, 0x05, 0x03, 0x03, 0x0c, 0x03, 0x0f, 0x03, 0x03, 0x05, 
0x03, 0x03, 0x05, 0x03, 0x03, 0x03, 0x03, 0x0f, 0x03, 0x0f, 0x0c, 0x0c, 0x03, 0x03, 0x0c, 0x03, 
0x0d, 0x0d, 0x0a, 0x0d, 0x0a, 0x0b, 0x0f, 0x01, 0x08, 0x05, 0x04, 0x02, 0x04, 0x05, 0x05, 0x02, 
0x04, 0x02, 0x02, 0x02, 0x04, 0x0d, 0x04, 0x05, 0x0f, 0x05, 0x03, 0x05, 0x03, 0x05, 0x05, 0x05, 
0x0d, 0x0d, 0x0a, 0x0d, 0x0a, 0x0b, 0x0f, 0x01, 0x08, 0x05, 0x04, 0x02, 0x04, 0x05, 0x05, 0x02, 
0x04, 0x02, 0x02, 0x02, 0x04, 0x0d, 0x04, 0x05, 0x0f, 0x05, 0x03, 0x05, 0x03, 0x05, 0x05, 0x05, 
0x0d, 0x0a, 0x0a, 0x0a, 0x0a, 0x0b, 0x0a, 0x00, 0x03, 0x04, 0x09, 0x06, 0x0d, 0x0d, 0x0a, 0x06, 
0x0a, 0x06, 0x0d, 0x09, 0x02, 0x0d, 0x04, 0x0d, 0x04, 0x05, 0x03, 0x05, 0x03, 0x04, 0x04, 0x04, 
0x0d, 0x0a, 0x0a, 0x0a, 0x0a, 0x0b, 0x0a, 0x00, 0x03, 0x04, 0x09, 0x06, 0x0d, 0x0d, 0x0a, 0x06, 
0x0a, 0x06, 0x0d, 0x09, 0x02, 0x0d, 0x04, 0x0d, 0x04, 0x05, 0x03, 0x05, 0x03, 0x04, 0x04, 0x04, 
0x0d, 0x0d, 0x0d, 0x0a, 0x0b, 0x0a, 0x09, 0x00, 0x04, 0x0d, 0x0d, 0x0d, 0x0f, 0x05, 0x0d, 0x0a, 
0x0b, 0x0d, 0x0d, 0x02, 0x01, 0x0d, 0x0d, 0x0d, 0x05, 0x04, 0x05, 0x03, 0x05, 0x05, 0x02, 0x04, 
0x0d, 0x0d, 0x0d, 0x0a, 0x0b, 0x0a, 0x09, 0x00, 0x04, 0x0d, 0x0d, 0x0d, 0x0f, 0x05, 0x0d, 0x0a, 
0x0b, 0x0d, 0x0d, 0x02, 0x01, 0x0d, 0x0d, 0x0d, 0x05, 0x04, 0x03, 0x05, 0x05, 0x05, 0x04, 0x04, 
0x0a, 0x0d, 0x0d, 0x06, 0x01, 0x06, 0x06, 0x00, 0x03, 0x03, 0x0b, 0x0b, 0x0f, 0x0b, 0x0d, 0x0d, 
0x0d, 0x0b, 0x0d, 0x02, 0x01, 0x04, 0x0d, 0x02, 0x05, 0x05, 0x05, 0x05, 0x05, 0x04, 0x05, 0x04, 
0x0a, 0x0d, 0x0d, 0x06, 0x01, 0x06, 0x06, 0x00, 0x03, 0x03, 0x0b, 0x0b, 0x0f, 0x0b, 0x0d, 0x0d, 
0x0d, 0x0b, 0x0d, 0x02, 0x01, 0x04, 0x0d, 0x02, 0x0b, 0x05, 0x04, 0x03, 0x05, 0x04, 0x04, 0x04, 
0x0d, 0x0d, 0x0a, 0x06, 0x06, 0x06, 0x01, 0x00, 0x03, 0x03, 0x0d, 0x0b, 0x0b, 0x0b, 0x0d, 0x0d, 
0x0d, 0x0b, 0x05, 0x09, 0x07, 0x0d, 0x0a, 0x05, 0x04, 0x05, 0x05, 0x03, 0x04, 0x05, 0x04, 0x0d, 
0x0d, 0x0d, 0x0a, 0x06, 0x06, 0x06, 0x01, 0x00, 0x03, 0x03, 0x0d, 0x0b, 0x0b, 0x0b, 0x0d, 0x0d, 
0x0d, 0x0b, 0x05, 0x09, 0x07, 0x04, 0x04, 0x0d, 0x04, 0x0f, 0x05, 0x05, 0x05, 0x04, 0x04, 0x05, 
0x0d, 0x0b, 0x06, 0x0a, 0x06, 0x0b, 0x0a, 0x00, 0x0f, 0x03, 0x0f, 0x05, 0x0b, 0x0d, 0x0b, 0x0b, 
0x0f, 0x0f, 0x03, 0x0a, 0x07, 0x0a, 0x02, 0x0d, 0x0f, 0x04, 0x05, 0x05, 0x05, 0x02, 0x04, 0x05, 
0x0d, 0x0b, 0x06, 0x0a, 0x06, 0x0b, 0x0a, 0x00, 0x0f, 0x03, 0x0f, 0x05, 0x0b, 0x0d, 0x0b, 0x0b, 
0x0f, 0x0f, 0x03, 0x0a, 0x07, 0x0a, 0x0a, 0x0d, 0x0f, 0x04, 0x05, 0x05, 0x05, 0x02, 0x04, 0x05, 
0x0d, 0x0b, 0x0a, 0x06, 0x06, 0x06, 0x0e, 0x00, 0x02, 0x07, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
0x07, 0x07, 0x01, 0x00, 0x07, 0x06, 0x02, 0x04, 0x0d, 0x04, 0x05, 0x02, 0x09, 0x06, 0x06, 0x0b, 
0x0d, 0x0b, 0x0a, 0x06, 0x06, 0x06, 0x0e, 0x00, 0x02, 0x07, 0x01, 0x01, 0x07, 0x09, 0x01, 0x07, 
0x07, 0x01, 0x07, 0x00, 0x01, 0x09, 0x02, 0x04, 0x04, 0x05, 0x0f, 0x02, 0x09, 0x09, 0x02, 0x05, 
0x00, 0x0e, 0x0e, 0x0e, 0x0e, 0x00, 0x0e, 0x0e, 0x04, 0x09, 0x07, 0x00, 0x00, 0x0e, 0x00, 0x00, 
0x0e, 0x00, 0x0e, 0x00, 0x07, 0x07, 0x09, 0x01, 0x09, 0x09, 0x09, 0x01, 0x07, 0x07, 0x07, 0x07, 
0x00, 0x0e, 0x0e, 0x0e, 0x0e, 0x00, 0x0e, 0x0e, 0x04, 0x09, 0x07, 0x00, 0x00, 0x0e, 0x00, 0x00, 
0x0e, 0x00, 0x0e, 0x00, 0x07, 0x07, 0x01, 0x01, 0x09, 0x09, 0x01, 0x01, 0x07, 0x07, 0x07, 0x07, 
0x06, 0x06, 0x06, 0x09, 0x06, 0x04, 0x04, 0x05, 0x05, 0x05, 0x05, 0x0d, 0x0d, 0x0d, 0x04, 0x05, 
0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x0c, 0x0c, 0x03, 0x0c, 0x03, 0x0c, 0x0f, 0x0d, 0x0d, 
0x06, 0x0a, 0x01, 0x09, 0x06, 0x04, 0x04, 0x05, 0x05, 0x05, 0x05, 0x0d, 0x0d, 0x0d, 0x04, 0x05, 
0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x0c, 0x03, 0x0c, 0x0c, 0x0c, 0x03, 0x0c, 0x0f, 0x05, 0x04, 
0x03, 0x0f, 0x0b, 0x0b, 0x0a, 0x06, 0x03, 0x0f, 0x03, 0x0c, 0x03, 0x0f, 0x0f, 0x04, 0x05, 0x03, 
0x0f, 0x05, 0x05, 0x04, 0x04, 0x05, 0x04, 0x0a, 0x05, 0x05, 0x05, 0x04, 0x05, 0x05, 0x06, 0x05, 
0x03, 0x0f, 0x0b, 0x0f, 0x0a, 0x06, 0x03, 0x0f, 0x03, 0x0c, 0x03, 0x0f, 0x0f, 0x04, 0x05, 0x03, 
0x0f, 0x05, 0x05, 0x04, 0x0d, 0x05, 0x0d, 0x04, 0x05, 0x05, 0x05, 0x04, 0x05, 0x05, 0x09, 0x0f, 
0x03, 0x03, 0x0c, 0x08, 0x0c, 0x0f, 0x08, 0x08, 0x08, 0x08, 0x08, 0x03, 0x03, 0x04, 0x09, 0x03, 
0x0f, 0x0f, 0x0f, 0x04, 0x0b, 0x0b, 0x0b, 0x04, 0x02, 0x05, 0x0d, 0x0b, 0x0d, 0x02, 0x0e, 0x0f, 
0x03, 0x03, 0x0c, 0x08, 0x0c, 0x0f, 0x08, 0x08, 0x08, 0x08, 0x08, 0x03, 0x0c, 0x02, 0x02, 0x03, 
0x0f, 0x0f, 0x0f, 0x04, 0x0d, 0x0b, 0x0b, 0x0a, 0x0a, 0x05, 0x0d, 0x05, 0x0d, 0x02, 0x0e, 0x03, 
0x0c, 0x08, 0x0c, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x05, 0x05, 0x04, 0x02, 0x07, 0x0c, 
0x0f, 0x03, 0x0b, 0x04, 0x0b, 0x0f, 0x0d, 0x0d, 0x0d, 0x0d, 0x05, 0x0f, 0x05, 0x0d, 0x00, 0x04, 
0x0c, 0x08, 0x0c, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x05, 0x04, 0x04, 0x02, 0x07, 0x0c, 
0x0f, 0x03, 0x0b, 0x04, 0x0b, 0x0f, 0x0d, 0x0d, 0x04, 0x0d, 0x05, 0x0f, 0x05, 0x0d, 0x00, 0x04, 
0x03, 0x03, 0x0f, 0x05, 0x05, 0x05, 0x05, 0x05, 0x03, 0x05, 0x04, 0x04, 0x02, 0x02, 0x0e, 0x03, 
0x0f, 0x0d, 0x0f, 0x0b, 0x05, 0x0b, 0x05, 0x0d, 0x0d, 0x05, 0x03, 0x0c, 0x04, 0x0f, 0x00, 0x03, 
0x03, 0x0f, 0x03, 0x05, 0x05, 0x05, 0x05, 0x05, 0x03, 0x05, 0x05, 0x04, 0x02, 0x02, 0x0e, 0x03, 
0x0b, 0x0b, 0x0f, 0x0b, 0x05, 0x0f, 0x05, 0x0d, 0x0d, 0x05, 0x03, 0x0c, 0x04, 0x05, 0x00, 0x03, 
0x05, 0x05, 0x05, 0x05, 0x03, 0x03, 0x03, 0x0f, 0x05, 0x0f, 0x05, 0x0a, 0x0d, 0x04, 0x01, 0x0c, 
0x0f, 0x03, 0x0b, 0x05, 0x04, 0x0d, 0x0d, 0x04, 0x05, 0x0f, 0x0f, 0x05, 0x0f, 0x0f, 0x0e, 0x0c, 
0x05, 0x0d, 0x05, 0x05, 0x03, 0x03, 0x03, 0x0f, 0x05, 0x0f, 0x05, 0x02, 0x0d, 0x04, 0x01, 0x0c, 
0x0f, 0x03, 0x0b, 0x05, 0x04, 0x0d, 0x0d, 0x04, 0x05, 0x0f, 0x0f, 0x05, 0x0f, 0x05, 0x0e, 0x03, 
0x0d, 0x02, 0x0d, 0x05, 0x0f, 0x03, 0x03, 0x05, 0x05, 0x05, 0x0f, 0x02, 0x04, 0x06, 0x00, 0x0c, 
0x0d, 0x0d, 0x0d, 0x05, 0x0d, 0x04, 0x0f, 0x05, 0x05, 0x05, 0x0f, 0x05, 0x03, 0x04, 0x0e, 0x03, 
0x0d, 0x02, 0x0d, 0x05, 0x0f, 0x03, 0x03, 0x05, 0x05, 0x05, 0x0f, 0x02, 0x04, 0x06, 0x00, 0x0c, 
0x0d, 0x0d, 0x0d, 0x0d, 0x04, 0x04, 0x0f, 0x05, 0x05, 0x05, 0x0f, 0x05, 0x03, 0x05, 0x0e, 0x0c, 
0x0d, 0x06, 0x05, 0x0d, 0x0f, 0x03, 0x05, 0x05, 0x04, 0x04, 0x02, 0x02, 0x02, 0x01, 0x00, 0x0f, 
0x0d, 0x0d, 0x0d, 0x0b, 0x05, 0x04, 0x05, 0x0f, 0x05, 0x05, 0x05, 0x05, 0x05, 0x04, 0x0e, 0x03, 
0x0d, 0x06, 0x05, 0x0d, 0x0f, 0x03, 0x05, 0x05, 0x04, 0x04, 0x0a, 0x02, 0x02, 0x01, 0x00, 0x0f, 
0x0a, 0x0b, 0x0d, 0x05, 0x05, 0x04, 0x05, 0x0f, 0x05, 0x0d, 0x05, 0x05, 0x0d, 0x04, 0x0e, 0x03, 
0x0f, 0x04, 0x0a, 0x0b, 0x05, 0x0c, 0x03, 0x05, 0x02, 0x06, 0x02, 0x06, 0x06, 0x07, 0x00, 0x03, 
0x0f, 0x0b, 0x0d, 0x04, 0x0d, 0x0d, 0x0d, 0x04, 0x05, 0x04, 0x05, 0x05, 0x03, 0x02, 0x00, 0x05, 
0x0f, 0x04, 0x0a, 0x05, 0x05, 0x0c, 0x0f, 0x05, 0x0a, 0x09, 0x02, 0x06, 0x09, 0x07, 0x00, 0x03, 
0x0f, 0x0b, 0x0d, 0x0d, 0x0d, 0x0b, 0x0d, 0x04, 0x05, 0x0d, 0x05, 0x05, 0x03, 0x02, 0x00, 0x04, 
0x0f, 0x02, 0x09, 0x01, 0x02, 0x02, 0x02, 0x02, 0x07, 0x0e, 0x09, 0x07, 0x0e, 0x00, 0x07, 0x0f, 
0x0a, 0x0d, 0x09, 0x06, 0x01, 0x06, 0x0e, 0x01, 0x0a, 0x05, 0x05, 0x04, 0x01, 0x00, 0x00, 0x04, 
0x0f, 0x02, 0x09, 0x01, 0x02, 0x02, 0x02, 0x02, 0x07, 0x07, 0x09, 0x07, 0x0e, 0x00, 0x01, 0x0f, 
0x0a, 0x04, 0x09, 0x06, 0x01, 0x09, 0x0e, 0x01, 0x0a, 0x05, 0x05, 0x04, 0x09, 0x00, 0x00, 0x04, 
0x03, 0x04, 0x02, 0x02, 0x06, 0x07, 0x00, 0x00, 0x00, 0x0e, 0x07, 0x01, 0x07, 0x09, 0x03, 0x03, 
0x06, 0x07, 0x07, 0x0e, 0x0e, 0x07, 0x0e, 0x09, 0x02, 0x07, 0x07, 0x07, 0x07, 0x01, 0x09, 0x0c, 
0x03, 0x04, 0x02, 0x02, 0x02, 0x07, 0x00, 0x00, 0x00, 0x0e, 0x07, 0x01, 0x07, 0x09, 0x03, 0x03, 
0x06, 0x07, 0x0e, 0x0e, 0x0e, 0x07, 0x0e, 0x09, 0x02, 0x07, 0x07, 0x07, 0x07, 0x07, 0x02, 0x0c, 
0x0f, 0x0f, 0x05, 0x05, 0x0d, 0x0f, 0x05, 0x0d, 0x0f, 0x03, 0x04, 0x02, 0x06, 0x0d, 0x09, 0x0a, 
0x0f, 0x04, 0x09, 0x0c, 0x08, 0x03, 0x08, 0x0c, 0x0c, 0x0c, 0x08, 0x0c, 0x0c, 0x03, 0x0c, 0x03, 
0x05, 0x03, 0x05, 0x0d, 0x0d, 0x0f, 0x05, 0x05, 0x05, 0x03, 0x04, 0x02, 0x06, 0x0a, 0x06, 0x0a, 
0x03, 0x0d, 0x09, 0x0c, 0x08, 0x0c, 0x08, 0x03, 0x0c, 0x0c, 0x08, 0x0c, 0x0c, 0x03, 0x0c, 0x0f, 
0x0d, 0x0b, 0x04, 0x0a, 0x0f, 0x0d, 0x0a, 0x0d, 0x0d, 0x0f, 0x0a, 0x06, 0x0b, 0x0f, 0x0f, 0x0d, 
0x0d, 0x09, 0x01, 0x08, 0x0f, 0x03, 0x0f, 0x03, 0x03, 0x03, 0x0c, 0x0c, 0x03, 0x0c, 0x03, 0x0c, 
0x0d, 0x0b, 0x0a, 0x0d, 0x0f, 0x0d, 0x0a, 0x0a, 0x0d, 0x0f, 0x0a, 0x06, 0x0d, 0x03, 0x0f, 0x0d, 
0x0a, 0x09, 0x01, 0x08, 0x0f, 0x03, 0x0f, 0x0c, 0x03, 0x03, 0x0c, 0x0c, 0x03, 0x0c, 0x03, 0x0c, 
0x0b, 0x0b, 0x06, 0x0d, 0x0b, 0x0a, 0x0a, 0x0a, 0x0d, 0x0d, 0x0d, 0x0a, 0x0b, 0x0f, 0x0f, 0x0b, 
0x0d, 0x01, 0x0e, 0x03, 0x0f, 0x03, 0x05, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x0c, 
0x0d, 0x0f, 0x06, 0x0a, 0x0b, 0x0a, 0x0d, 0x0a, 0x0b, 0x0d, 0x0d, 0x0a, 0x0b, 0x0b, 0x0f, 0x0b, 
0x0b, 0x01, 0x0e, 0x03, 0x0f, 0x0f, 0x05, 0x03, 0x03, 0x03, 0x03, 0x03, 0x0c, 0x03, 0x03, 0x0c, 
0x0b, 0x0b, 0x06, 0x0d, 0x0d, 0x0a, 0x0d, 0x0d, 0x0b, 0x0b, 0x0a, 0x0a, 0x0b, 0x0b, 0x0a, 0x0d, 
0x0d, 0x09, 0x07, 0x03, 0x0d, 0x05, 0x05, 0x03, 0x05, 0x03, 0x03, 0x03, 0x03, 0x03, 0x0a, 0x09, 
0x0b, 0x0b, 0x06, 0x0d, 0x0d, 0x0a, 0x0d, 0x0a, 0x0b, 0x0b, 0x0a, 0x0a, 0x0b, 0x0b, 0x0a, 0x0b, 
0x0d, 0x09, 0x07, 0x03, 0x0d, 0x05, 0x05, 0x03, 0x05, 0x0f, 0x03, 0x03, 0x0f, 0x03, 0x0a, 0x09, 
0x0a, 0x06, 0x06, 0x0d, 0x0d, 0x0b, 0x0d, 0x0b, 0x0b, 0x0b, 0x0a, 0x0a, 0x0b, 0x0b, 0x0d, 0x0b, 
0x0d, 0x09, 0x07, 0x03, 0x04, 0x05, 0x05, 0x05, 0x0f, 0x03, 0x0f, 0x05, 0x0f, 0x03, 0x02, 0x06, 
0x0a, 0x06, 0x06, 0x0d, 0x0d, 0x0b, 0x0d, 0x0b, 0x0b, 0x0b, 0x0a, 0x0a, 0x0b, 0x0b, 0x0d, 0x0b, 
0x0d, 0x09, 0x07, 0x03, 0x04, 0x05, 0x05, 0x05, 0x0f, 0x03, 0x0f, 0x05, 0x0f, 0x03, 0x02, 0x06, 
0x0d, 0x0a, 0x0a, 0x0a, 0x0a, 0x0b, 0x0f, 0x0b, 0x0b, 0x0b, 0x0d, 0x0b, 0x0f, 0x0f, 0x0f, 0x0f, 
0x0f, 0x06, 0x0e, 0x0f, 0x0d, 0x0f, 0x0f, 0x03, 0x03, 0x03, 0x0f, 0x03, 0x03, 0x0f, 0x0a, 0x06, 
0x0d, 0x0a, 0x0a, 0x0a, 0x0a, 0x0b, 0x0f, 0x0b, 0x0b, 0x0b, 0x0d, 0x0b, 0x0f, 0x0b, 0x0f, 0x0f, 
0x0f, 0x06, 0x0e, 0x03, 0x0d, 0x0f, 0x0f, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x0f, 0x02, 0x06, 
0x0d, 0x0a, 0x06, 0x0d, 0x0b, 0x0d, 0x0f, 0x0b, 0x0f, 0x0f, 0x0f, 0x0f, 0x03, 0x0f, 0x03, 0x03, 
0x0f, 0x0a, 0x00, 0x03, 0x05, 0x0f, 0x0f, 0x0f, 0x05, 0x05, 0x05, 0x0f, 0x0f, 0x04, 0x01, 0x01, 
0x0b, 0x0a, 0x06, 0x0d, 0x0b, 0x0d, 0x03, 0x0d, 0x0f, 0x0f, 0x0f, 0x03, 0x03, 0x0f, 0x03, 0x03, 
0x0f, 0x0a, 0x00, 0x03, 0x05, 0x0f, 0x0f, 0x0f, 0x05, 0x05, 0x05, 0x05, 0x0f, 0x04, 0x01, 0x01, 
0x0a, 0x06, 0x0a, 0x0d, 0x0a, 0x0a, 0x0a, 0x0d, 0x0f, 0x0b, 0x0b, 0x0f, 0x0f, 0x0f, 0x03, 0x03, 
0x03, 0x02, 0x00, 0x0c, 0x03, 0x0f, 0x03, 0x03, 0x0f, 0x05, 0x03, 0x03, 0x0c, 0x0d, 0x0a, 0x0d, 
0x0a, 0x06, 0x0a, 0x0a, 0x0a, 0x0a, 0x0d, 0x0d, 0x0f, 0x0b, 0x0b, 0x0f, 0x0f, 0x0f, 0x03, 0x0c, 
0x0f, 0x02, 0x00, 0x03, 0x03, 0x03, 0x03, 0x03, 0x0f, 0x05, 0x03, 0x03, 0x0c, 0x05, 0x0a, 0x05, 
0x0a, 0x06, 0x06, 0x0a, 0x0a, 0x0a, 0x0a, 0x0d, 0x0b, 0x0a, 0x0b, 0x0f, 0x03, 0x0f, 0x03, 0x0d, 
0x0a, 0x09, 0x00, 0x03, 0x08, 0x0c, 0x0f, 0x0d, 0x05, 0x05, 0x0f, 0x03, 0x04, 0x09, 0x0d, 0x0f, 
0x0a, 0x06, 0x0a, 0x0a, 0x06, 0x0a, 0x0a, 0x0d, 0x0b, 0x0a, 0x0d, 0x03, 0x03, 0x0f, 0x0f, 0x0d, 
0x0a, 0x09, 0x00, 0x03, 0x08, 0x03, 0x03, 0x04, 0x05, 0x05, 0x0f, 0x03, 0x04, 0x09, 0x04, 0x0f, 
0x06, 0x06, 0x0a, 0x0a, 0x0b, 0x0a, 0x0a, 0x0d, 0x0a, 0x0a, 0x0f, 0x0f, 0x0a, 0x06, 0x0b, 0x0a, 
0x0a, 0x09, 0x00, 0x05, 0x03, 0x0f, 0x04, 0x04, 0x05, 0x03, 0x04, 0x09, 0x0e, 0x01, 0x0d, 0x0b, 
0x06, 0x06, 0x0a, 0x0a, 0x0b, 0x0a, 0x0a, 0x0a, 0x0d, 0x0a, 0x0b, 0x0f, 0x0a, 0x06, 0x0b, 0x0a, 
0x0d, 0x09, 0x00, 0x05, 0x03, 0x0f, 0x04, 0x04, 0x0f, 0x03, 0x04, 0x09, 0x0e, 0x01, 0x0d, 0x05, 
0x00, 0x0e, 0x07, 0x00, 0x0e, 0x07, 0x0e, 0x0e, 0x00, 0x0e, 0x09, 0x01, 0x0a, 0x06, 0x09, 0x09, 
0x06, 0x0e, 0x00, 0x0c, 0x04, 0x09, 0x01, 0x01, 0x07, 0x0e, 0x00, 0x00, 0x00, 0x00, 0x01, 0x07, 
0x00, 0x0e, 0x07, 0x0e, 0x0e, 0x07, 0x0e, 0x0e, 0x00, 0x0e, 0x09, 0x01, 0x02, 0x06, 0x09, 0x09, 
0x06, 0x0e, 0x00, 0x0c, 0x04, 0x09, 0x01, 0x07, 0x07, 0x0e, 0x00, 0x00, 0x00, 0x0e, 0x07, 0x07, 
0x06, 0x06, 0x0a, 0x0a, 0x06, 0x0a, 0x0a, 0x0b, 0x03, 0x0f, 0x0f, 0x04, 0x01, 0x01, 0x01, 0x01, 
0x01, 0x01, 0x02, 0x03, 0x0c, 0x0c, 0x0c, 0x04, 0x04, 0x02, 0x02, 0x04, 0x06, 0x09, 0x06, 0x06, 
0x06, 0x06, 0x0a, 0x0a, 0x06, 0x0a, 0x0a, 0x0b, 0x03, 0x0f, 0x0f, 0x04, 0x01, 0x01, 0x01, 0x01, 
0x01, 0x01, 0x02, 0x03, 0x0c, 0x0c, 0x0c, 0x05, 0x02, 0x02, 0x02, 0x04, 0x09, 0x09, 0x02, 0x09, 
0x0b, 0x0b, 0x0d, 0x0b, 0x0d, 0x0b, 0x05, 0x05, 0x03, 0x03, 0x0c, 0x03, 0x03, 0x03, 0x0c, 0x0f, 
0x03, 0x03, 0x05, 0x03, 0x03, 0x03, 0x03, 0x05, 0x03, 0x05, 0x0c, 0x0c, 0x03, 0x03, 0x0c, 0x03, 
0x0d, 0x0b, 0x0d, 0x0b, 0x0d, 0x0b, 0x05, 0x05, 0x03, 0x0c, 0x03, 0x0c, 0x0f, 0x03, 0x03, 0x0f, 
0x03, 0x03, 0x05, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x05, 0x0c, 0x0c, 0x03, 0x03, 0x0c, 0x03, 
0x0d, 0x0d, 0x0a, 0x0d, 0x0a, 0x0f, 0x05, 0x09, 0x0c, 0x0f, 0x04, 0x09, 0x0d, 0x0d, 0x0d, 0x02, 
0x04, 0x02, 0x02, 0x02, 0x04, 0x04, 0x04, 0x05, 0x05, 0x05, 0x03, 0x05, 0x03, 0x05, 0x05, 0x0b, 
0x0b, 0x0a, 0x0a, 0x0d, 0x0a, 0x0f, 0x0f, 0x01, 0x0c, 0x0f, 0x04, 0x09, 0x0d, 0x05, 0x0d, 0x02, 
0x04, 0x02, 0x02, 0x02, 0x04, 0x04, 0x04, 0x04, 0x05, 0x05, 0x03, 0x05, 0x03, 0x05, 0x05, 0x05, 
0x0d, 0x0a, 0x0a, 0x0a, 0x0a, 0x0b, 0x0a, 0x00, 0x03, 0x04, 0x06, 0x02, 0x0d, 0x0d, 0x0a, 0x02, 
0x06, 0x0a, 0x04, 0x09, 0x02, 0x04, 0x0d, 0x05, 0x04, 0x05, 0x03, 0x05, 0x03, 0x04, 0x04, 0x04, 
0x0d, 0x0a, 0x0a, 0x0a, 0x0a, 0x0b, 0x0a, 0x00, 0x03, 0x04, 0x02, 0x06, 0x0d, 0x0d, 0x0a, 0x02, 
0x06, 0x0a, 0x0d, 0x09, 0x02, 0x05, 0x04, 0x05, 0x04, 0x05, 0x03, 0x05, 0x03, 0x04, 0x04, 0x04, 
0x0d, 0x0d, 0x0d, 0x0a, 0x0b, 0x0a, 0x01, 0x00, 0x04, 0x0d, 0x0d, 0x0d, 0x05, 0x05, 0x0d, 0x0a, 
0x0b, 0x0d, 0x0d, 0x02, 0x01, 0x04, 0x0d, 0x04, 0x05, 0x04, 0x03, 0x03, 0x04, 0x05, 0x04, 0x0a, 
0x0b, 0x0d, 0x0d, 0x0a, 0x0b, 0x0a, 0x09, 0x00, 0x04, 0x0d, 0x0d, 0x05, 0x05, 0x0f, 0x0d, 0x0a, 
0x0b, 0x0d, 0x04, 0x02, 0x01, 0x04, 0x0d, 0x04, 0x05, 0x04, 0x03, 0x05, 0x05, 0x05, 0x04, 0x04, 
0x0a, 0x0b, 0x0a, 0x06, 0x06, 0x06, 0x06, 0x00, 0x0f, 0x0c, 0x0b, 0x0b, 0x0f, 0x0b, 0x0d, 0x0d, 
0x0d, 0x0d, 0x0d, 0x02, 0x01, 0x04, 0x0d, 0x02, 0x05, 0x0d, 0x04, 0x03, 0x05, 0x04, 0x04, 0x04, 
0x0a, 0x0d, 0x0d, 0x06, 0x01, 0x06, 0x06, 0x00, 0x0f, 0x03, 0x0b, 0x0b, 0x0f, 0x0b, 0x0d, 0x0d, 
0x0d, 0x0b, 0x0d, 0x02, 0x01, 0x0d, 0x0d, 0x02, 0x05, 0x05, 0x04, 0x03, 0x05, 0x04, 0x04, 0x04, 
0x0a, 0x0b, 0x0a, 0x06, 0x06, 0x06, 0x01, 0x00, 0x03, 0x0f, 0x0d, 0x0b, 0x0b, 0x0b, 0x0b, 0x0d, 
0x0d, 0x0f, 0x05, 0x09, 0x07, 0x0d, 0x0a, 0x05, 0x04, 0x03, 0x05, 0x05, 0x04, 0x05, 0x04, 0x0d, 
0x0d, 0x0d, 0x0a, 0x06, 0x06, 0x06, 0x01, 0x00, 0x03, 0x0f, 0x0d, 0x0d, 0x0b, 0x0b, 0x0b, 0x0d, 
0x0d, 0x0f, 0x0d, 0x09, 0x07, 0x04, 0x04, 0x0d, 0x05, 0x05, 0x05, 0x03, 0x04, 0x05, 0x04, 0x05, 
0x0d, 0x0b, 0x06, 0x06, 0x06, 0x0b, 0x0a, 0x00, 0x0f, 0x03, 0x0f, 0x0f, 0x0b, 0x0a, 0x0b, 0x0b, 
0x0b, 0x0f, 0x03, 0x0a, 0x07, 0x04, 0x02, 0x0d, 0x0f, 0x04, 0x05, 0x05, 0x03, 0x02, 0x04, 0x05, 
0x0d, 0x0b, 0x06, 0x0a, 0x06, 0x0b, 0x0a, 0x00, 0x0f, 0x03, 0x0f, 0x0f, 0x0b, 0x0a, 0x0b, 0x0b, 
0x0b, 0x0f, 0x03, 0x0a, 0x07, 0x0a, 0x02, 0x0d, 0x0f, 0x04, 0x05, 0x05, 0x05, 0x02, 0x04, 0x05, 
0x0d, 0x0b, 0x0a, 0x06, 0x06, 0x06, 0x0e, 0x00, 0x02, 0x07, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
0x07, 0x01, 0x01, 0x00, 0x07, 0x06, 0x06, 0x04, 0x04, 0x05, 0x05, 0x02, 0x09, 0x06, 0x06, 0x0b, 
0x0a, 0x0b, 0x0a, 0x06, 0x06, 0x06, 0x0e, 0x00, 0x02, 0x07, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
0x07, 0x01, 0x07, 0x0e, 0x07, 0x06, 0x02, 0x04, 0x04, 0x04, 0x05, 0x02, 0x09, 0x09, 0x06, 0x05, 
0x00, 0x0e, 0x07, 0x0e, 0x0e, 0x00, 0x0e, 0x07, 0x02, 0x09, 0x07, 0x00, 0x00, 0x0e, 0x00, 0x00, 
0x00, 0x00, 0x0e, 0x00, 0x07, 0x07, 0x09, 0x01, 0x01, 0x09, 0x09, 0x01, 0x07, 0x07, 0x07, 0x07, 
0x0e, 0x0e, 0x0e, 0x0e, 0x0e, 0x00, 0x0e, 0x07, 0x02, 0x09, 0x07, 0x00, 0x00, 0x0e, 0x00, 0x00, 
0x00, 0x00, 0x0e, 0x00, 0x07, 0x07, 0x01, 0x01, 0x09, 0x09, 0x09, 0x01, 0x07, 0x07, 0x07, 0x07, 
0x09, 0x0a, 0x01, 0x09, 0x06, 0x04, 0x04, 0x05, 0x05, 0x05, 0x05, 0x0d, 0x0d, 0x05, 0x04, 0x05, 
0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x0c, 0x0c, 0x0c, 0x03, 0x0c, 0x03, 0x03, 0x0f, 0x0b, 0x0a, 
0x06, 0x0a, 0x01, 0x09, 0x06, 0x04, 0x04, 0x05, 0x05, 0x05, 0x0f, 0x0d, 0x04, 0x05, 0x04, 0x05, 
0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x0c, 0x0c, 0x0c, 0x0c, 0x0c, 0x0c, 0x03, 0x03, 0x05, 0x04, 
0x03, 0x0f, 0x0b, 0x0f, 0x0a, 0x09, 0x03, 0x0f, 0x03, 0x0c, 0x03, 0x0f, 0x0f, 0x04, 0x05, 0x03, 
0x0f, 0x05, 0x05, 0x04, 0x0d, 0x05, 0x04, 0x0a, 0x05, 0x05, 0x05, 0x0d, 0x05, 0x05, 0x06, 0x0f, 
0x03, 0x0b, 0x0b, 0x0f, 0x0a, 0x06, 0x03, 0x0f, 0x03, 0x0c, 0x03, 0x0f, 0x0f, 0x04, 0x05, 0x03, 
0x03, 0x05, 0x05, 0x04, 0x0d, 0x05, 0x04, 0x0a, 0x0d, 0x05, 0x04, 0x04, 0x05, 0x05, 0x09, 0x0f, 
0x03, 0x03, 0x0c, 0x08, 0x0c, 0x03, 0x08, 0x08, 0x08, 0x08, 0x08, 0x03, 0x03, 0x02, 0x02, 0x03, 
0x0f, 0x0f, 0x0f, 0x04, 0x0d, 0x0b, 0x0b, 0x04, 0x0a, 0x05, 0x0d, 0x0f, 0x0d, 0x02, 0x0e, 0x0f, 
0x03, 0x03, 0x0c, 0x08, 0x0c, 0x0f, 0x08, 0x08, 0x08, 0x08, 0x08, 0x03, 0x0c, 0x02, 0x02, 0x03, 
0x0f, 0x0f, 0x0f, 0x04, 0x0d, 0x0b, 0x0b, 0x04, 0x0a, 0x05, 0x05, 0x05, 0x0d, 0x02, 0x0e, 0x03, 
0x0c, 0x08, 0x0c, 0x03, 0x0f, 0x03, 0x03, 0x03, 0x03, 0x03, 0x05, 0x05, 0x04, 0x02, 0x07, 0x0c, 
0x0f, 0x03, 0x0b, 0x04, 0x0b, 0x0f, 0x0d, 0x0d, 0x04, 0x0d, 0x05, 0x0f, 0x05, 0x0d, 0x00, 0x04, 
0x0c, 0x08, 0x0c, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x05, 0x04, 0x04, 0x02, 0x07, 0x0c, 
0x0f, 0x0f, 0x0f, 0x04, 0x0f, 0x0f, 0x0d, 0x0d, 0x04, 0x0d, 0x05, 0x0f, 0x05, 0x0d, 0x00, 0x04, 
0x03, 0x0f, 0x03, 0x05, 0x05, 0x0f, 0x05, 0x05, 0x03, 0x05, 0x04, 0x04, 0x02, 0x02, 0x0e, 0x0c, 
0x0b, 0x0b, 0x0f, 0x0b, 0x05, 0x0b, 0x05, 0x0d, 0x0d, 0x05, 0x03, 0x03, 0x04, 0x0f, 0x00, 0x03, 
0x0c, 0x0f, 0x03, 0x05, 0x05, 0x0f, 0x05, 0x05, 0x03, 0x05, 0x05, 0x04, 0x02, 0x02, 0x0e, 0x03, 
0x0f, 0x0b, 0x05, 0x05, 0x0b, 0x05, 0x05, 0x0d, 0x04, 0x0f, 0x0f, 0x0c, 0x04, 0x05, 0x00, 0x03, 
0x0f, 0x0d, 0x05, 0x05, 0x03, 0x03, 0x03, 0x0f, 0x0f, 0x0f, 0x05, 0x0a, 0x0d, 0x04, 0x01, 0x0c, 
0x0b, 0x03, 0x0b, 0x05, 0x04, 0x0d, 0x05, 0x04, 0x05, 0x0f, 0x03, 0x05, 0x0f, 0x05, 0x0e, 0x03, 
0x05, 0x0d, 0x05, 0x05, 0x03, 0x03, 0x03, 0x0f, 0x0f, 0x05, 0x05, 0x02, 0x0d, 0x04, 0x01, 0x0c, 
0x0f, 0x03, 0x0b, 0x05, 0x0d, 0x0d, 0x05, 0x04, 0x05, 0x0f, 0x0f, 0x05, 0x0f, 0x05, 0x0e, 0x03, 
0x0d, 0x02, 0x0d, 0x05, 0x0f, 0x03, 0x03, 0x05, 0x05, 0x05, 0x0f, 0x02, 0x04, 0x09, 0x00, 0x0c, 
0x0d, 0x0d, 0x0d, 0x05, 0x04, 0x0d, 0x05, 0x05, 0x05, 0x05, 0x0f, 0x05, 0x03, 0x05, 0x0e, 0x03, 
0x0d, 0x02, 0x0d, 0x05, 0x0f, 0x03, 0x03, 0x05, 0x05, 0x05, 0x0f, 0x02, 0x04, 0x06, 0x00, 0x0c, 
0x0d, 0x0d, 0x0d, 0x0d, 0x04, 0x04, 0x0f, 0x05, 0x05, 0x05, 0x0f, 0x05, 0x03, 0x05, 0x0e, 0x0c, 
0x0d, 0x06, 0x05, 0x0d, 0x0f, 0x03, 0x05, 0x05, 0x04, 0x04, 0x02, 0x02, 0x02, 0x01, 0x00, 0x0f, 
0x0d, 0x0d, 0x0d, 0x0b, 0x05, 0x04, 0x05, 0x0f, 0x05, 0x04, 0x05, 0x05, 0x0d, 0x04, 0x0e, 0x0c, 
0x0d, 0x06, 0x05, 0x04, 0x0f, 0x03, 0x05, 0x05, 0x04, 0x04, 0x0a, 0x02, 0x02, 0x01, 0x00, 0x0f, 
0x0a, 0x0b, 0x0d, 0x0b, 0x05, 0x0a, 0x05, 0x03, 0x05, 0x0d, 0x05, 0x05, 0x0d, 0x04, 0x0e, 0x03, 
0x0f, 0x0a, 0x04, 0x0d, 0x0f, 0x0c, 0x0f, 0x05, 0x02, 0x06, 0x02, 0x06, 0x06, 0x07, 0x00, 0x03, 
0x0f, 0x0b, 0x0d, 0x04, 0x0d, 0x0b, 0x0d, 0x04, 0x05, 0x0d, 0x05, 0x05, 0x03, 0x02, 0x00, 0x04, 
0x0f, 0x04, 0x0a, 0x05, 0x0f, 0x0c, 0x0f, 0x0b, 0x02, 0x09, 0x02, 0x06, 0x09, 0x07, 0x00, 0x03, 
0x0f, 0x0b, 0x0d, 0x0d, 0x05, 0x05, 0x0d, 0x04, 0x05, 0x04, 0x05, 0x05, 0x03, 0x02, 0x00, 0x04, 
0x0f, 0x02, 0x09, 0x01, 0x02, 0x02, 0x02, 0x02, 0x07, 0x07, 0x09, 0x07, 0x0e, 0x00, 0x07, 0x0f, 
0x0a, 0x0d, 0x09, 0x06, 0x01, 0x09, 0x0e, 0x01, 0x0a, 0x05, 0x05, 0x04, 0x09, 0x00, 0x00, 0x04, 
0x0f, 0x02, 0x09, 0x01, 0x02, 0x02, 0x02, 0x02, 0x07, 0x07, 0x09, 0x07, 0x0e, 0x00, 0x01, 0x0f, 
0x0a, 0x04, 0x01, 0x06, 0x01, 0x09, 0x0e, 0x01, 0x0a, 0x05, 0x05, 0x04, 0x09, 0x00, 0x00, 0x04, 
0x03, 0x04, 0x02, 0x02, 0x02, 0x07, 0x00, 0x00, 0x00, 0x0e, 0x07, 0x07, 0x07, 0x09, 0x03, 0x03, 
0x06, 0x07, 0x0e, 0x0e, 0x0e, 0x07, 0x0e, 0x09, 0x02, 0x07, 0x07, 0x07, 0x07, 0x07, 0x02, 0x0c, 
0x03, 0x04, 0x02, 0x02, 0x02, 0x07, 0x00, 0x00, 0x00, 0x0e, 0x07, 0x07, 0x07, 0x09, 0x03, 0x03, 
0x06, 0x07, 0x07, 0x0e, 0x0e, 0x07, 0x0e, 0x09, 0x02, 0x07, 0x07, 0x07, 0x07, 0x07, 0x02, 0x0c, 
0x0f, 0x0f, 0x05, 0x0d, 0x0d, 0x0f, 0x05, 0x05, 0x05, 0x03, 0x05, 0x02, 0x02, 0x0a, 0x06, 0x0a, 
0x0f, 0x0d, 0x09, 0x0c, 0x08, 0x03, 0x08, 0x0c, 0x0c, 0x0c, 0x08, 0x0c, 0x0c, 0x03, 0x0c, 0x05, 
0x0f, 0x0f, 0x05, 0x0d, 0x0d, 0x0f, 0x05, 0x05, 0x0f, 0x03, 0x05, 0x02, 0x06, 0x04, 0x06, 0x0a, 
0x03, 0x04, 0x09, 0x0c, 0x08, 0x03, 0x08, 0x0c, 0x0c, 0x0c, 0x08, 0x0c, 0x0c, 0x03, 0x0c, 0x0f, 
0x0d, 0x0b, 0x0a, 0x04, 0x0f, 0x0d, 0x0a, 0x0d, 0x0a, 0x0f, 0x0a, 0x06, 0x0d, 0x03, 0x0f, 0x0d, 
0x0d, 0x09, 0x01, 0x08, 0x0f, 0x03, 0x0f, 0x03, 0x03, 0x03, 0x0c, 0x0c, 0x03, 0x0c, 0x03, 0x0c, 
0x0d, 0x0b, 0x0a, 0x04, 0x0f, 0x0d, 0x0a, 0x0d, 0x0a, 0x0f, 0x0a, 0x06, 0x0d, 0x0f, 0x0f, 0x0d, 
0x0a, 0x09, 0x01, 0x08, 0x0f, 0x03, 0x0f, 0x03, 0x03, 0x03, 0x0c, 0x0c, 0x03, 0x0c, 0x03, 0x0c, 
0x0b, 0x0f, 0x06, 0x0a, 0x0b, 0x0a, 0x0a, 0x0a, 0x0b, 0x0d, 0x0d, 0x0a, 0x0b, 0x0b, 0x0f, 0x0b, 
0x0b, 0x01, 0x0e, 0x03, 0x0f, 0x03, 0x05, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x0c, 0x03, 0x0c, 
0x0b, 0x0f, 0x06, 0x0a, 0x0b, 0x0a, 0x0a, 0x0a, 0x0b, 0x0d, 0x0d, 0x0a, 0x0f, 0x0b, 0x0f, 0x0b, 
0x0b, 0x01, 0x0e, 0x03, 0x0f, 0x03, 0x05, 0x03, 0x03, 0x03, 0x03, 0x03, 0x0c, 0x03, 0x03, 0x0c, 
0x0b, 0x0d, 0x0a, 0x0d, 0x0d, 0x0a, 0x0d, 0x0d, 0x0b, 0x0b, 0x0a, 0x0a, 0x0b, 0x0b, 0x0a, 0x0d, 
0x0d, 0x09, 0x07, 0x03, 0x0d, 0x05, 0x05, 0x03, 0x05, 0x0f, 0x03, 0x03, 0x0f, 0x03, 0x04, 0x09, 
0x0b, 0x0d, 0x0a, 0x0d, 0x0d, 0x0a, 0x0d, 0x0d, 0x0b, 0x0b, 0x0d, 0x06, 0x0b, 0x0b, 0x0a, 0x0b, 
0x0d, 0x09, 0x07, 0x03, 0x0d, 0x05, 0x05, 0x03, 0x05, 0x03, 0x03, 0x03, 0x0f, 0x03, 0x0a, 0x09, 
0x0a, 0x06, 0x06, 0x0d, 0x0d, 0x0b, 0x0d, 0x0b, 0x0d, 0x0b, 0x0a, 0x0a, 0x0b, 0x0b, 0x0d, 0x0b, 
0x0d, 0x09, 0x07, 0x03, 0x04, 0x05, 0x05, 0x05, 0x0f, 0x03, 0x03, 0x05, 0x0f, 0x0f, 0x06, 0x02, 
0x0a, 0x06, 0x06, 0x0d, 0x0d, 0x0b, 0x0d, 0x0b, 0x0d, 0x0b, 0x0a, 0x0a, 0x0f, 0x0b, 0x0d, 0x0b, 
0x0d, 0x09, 0x07, 0x03, 0x04, 0x05, 0x05, 0x05, 0x0f, 0x03, 0x0f, 0x05, 0x0f, 0x03, 0x02, 0x06, 
0x0b, 0x06, 0x0a, 0x0a, 0x0a, 0x0b, 0x0f, 0x0b, 0x0b, 0x0f, 0x0a, 0x0b, 0x0f, 0x0b, 0x0f, 0x03, 
0x0f, 0x06, 0x0e, 0x0f, 0x0d, 0x0f, 0x0f, 0x03, 0x03, 0x03, 0x0f, 0x03, 0x03, 0x0f, 0x0a, 0x06, 
0x0d, 0x0a, 0x06, 0x0a, 0x0a, 0x0b, 0x0f, 0x0b, 0x0b, 0x0b, 0x0d, 0x0b, 0x0f, 0x0b, 0x0f, 0x0f, 
0x0f, 0x02, 0x0e, 0x0f, 0x0d, 0x0f, 0x0f, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x0f, 0x02, 0x06, 
0x0d, 0x0a, 0x0a, 0x0a, 0x0b, 0x0d, 0x03, 0x0b, 0x0b, 0x0f, 0x03, 0x03, 0x03, 0x0f, 0x03, 0x03, 
0x0f, 0x0a, 0x00, 0x03, 0x05, 0x0f, 0x0f, 0x0f, 0x05, 0x05, 0x05, 0x05, 0x03, 0x04, 0x01, 0x01, 
0x0b, 0x0a, 0x0a, 0x0a, 0x0b, 0x0d, 0x03, 0x0b, 0x0b, 0x0f, 0x0f, 0x0f, 0x03, 0x0f, 0x03, 0x03, 
0x0b, 0x0a, 0x00, 0x03, 0x05, 0x0f, 0x0f, 0x0f, 0x05, 0x05, 0x05, 0x05, 0x0f, 0x04, 0x01, 0x01, 
0x0a, 0x06, 0x0a, 0x0d, 0x0a, 0x0a, 0x0a, 0x0d, 0x0f, 0x0b, 0x0d, 0x0f, 0x0f, 0x0f, 0x0f, 0x0c, 
0x0f, 0x02, 0x00, 0x0c, 0x03, 0x03, 0x03, 0x03, 0x0f, 0x05, 0x03, 0x03, 0x0c, 0x0d, 0x0a, 0x0d, 
0x0a, 0x06, 0x0a, 0x0d, 0x0a, 0x0a, 0x0a, 0x0d, 0x0f, 0x0b, 0x0b, 0x0f, 0x0f, 0x0f, 0x03, 0x0c, 
0x0f, 0x02, 0x00, 0x0c, 0x03, 0x0f, 0x03, 0x03, 0x0f, 0x05, 0x03, 0x03, 0x0c, 0x05, 0x0a, 0x05, 
0x0a, 0x06, 0x06, 0x0a, 0x0a, 0x0a, 0x0a, 0x0b, 0x0b, 0x0a, 0x0b, 0x0f, 0x03, 0x0f, 0x0f, 0x0b, 
0x0a, 0x09, 0x00, 0x03, 0x08, 0x03, 0x0f, 0x0d, 0x05, 0x05, 0x0f, 0x03, 0x04, 0x09, 0x0d, 0x0f, 
0x0a, 0x06, 0x06, 0x0a, 0x0a, 0x0a, 0x0a, 0x0d, 0x0b, 0x0a, 0x0b, 0x0f, 0x03, 0x0f, 0x0f, 0x0b, 
0x0a, 0x09, 0x00, 0x03, 0x08, 0x0c, 0x0f, 0x0d, 0x04, 0x05, 0x0f, 0x03, 0x04, 0x09, 0x04, 0x0f, 
0x06, 0x06, 0x0a, 0x0a, 0x0b, 0x0a, 0x0a, 0x0a, 0x0d, 0x0a, 0x0f, 0x0f, 0x0d, 0x06, 0x0b, 0x06, 
0x0d, 0x09, 0x00, 0x05, 0x03, 0x0f, 0x04, 0x04, 0x0f, 0x03, 0x04, 0x09, 0x0e, 0x01, 0x0d, 0x0b, 
0x06, 0x06, 0x0a, 0x0a, 0x0b, 0x0a, 0x0a, 0x0a, 0x0d, 0x0a, 0x0f, 0x0b, 0x0d, 0x06, 0x0b, 0x0a, 
0x0a, 0x09, 0x00, 0x05, 0x03, 0x0f, 0x04, 0x04, 0x0f, 0x03, 0x04, 0x09, 0x0e, 0x01, 0x0d, 0x05, 
0x00, 0x0e, 0x07, 0x0e, 0x0e, 0x07, 0x0e, 0x0e, 0x00, 0x0e, 0x01, 0x09, 0x06, 0x06, 0x09, 0x06, 
0x06, 0x0e, 0x00, 0x03, 0x04, 0x02, 0x07, 0x01, 0x07, 0x0e, 0x00, 0x00, 0x00, 0x00, 0x01, 0x07, 
0x00, 0x0e, 0x07, 0x00, 0x0e, 0x07, 0x07, 0x0e, 0x00, 0x0e, 0x09, 0x01, 0x06, 0x06, 0x09, 0x09, 
0x06, 0x0e, 0x00, 0x0c, 0x04, 0x09, 0x01, 0x01, 0x07, 0x0e, 0x00, 0x00, 0x00, 0x0e, 0x07, 0x07, 
0x06, 0x06, 0x06, 0x0a, 0x06, 0x0a, 0x0a, 0x0b, 0x03, 0x0f, 0x0f, 0x04, 0x01, 0x01, 0x01, 0x01, 
0x01, 0x01, 0x04, 0x03, 0x0c, 0x0c, 0x0c, 0x05, 0x02, 0x02, 0x02, 0x04, 0x06, 0x09, 0x06, 0x06, 
0x06, 0x06, 0x0a, 0x0a, 0x06, 0x0a, 0x0a, 0x0d, 0x03, 0x0f, 0x0f, 0x04, 0x01, 0x01, 0x01, 0x01, 
0x01, 0x01, 0x02, 0x03, 0x0c, 0x0c, 0x0c, 0x05, 0x02, 0x02, 0x02, 0x04, 0x09, 0x09, 0x02, 0x09
};

